##  Configuring Rings and Sectors for Fact Sheet Classification
Fact sheets are categorized based on values of feact sheet fields or tags that are assigned to rings and sectors. It can be configured in report settings.
  1. Select Settings at the top right corner of the report. It opens the report settings dialog.
  2. In the report settings dialog, select the field or tag from the drop down menu for Ring Category and Sector Category.
  3. Click Apply.


Only single-select fields and tag groups can be assigned to rings and sectors, and the order of the rings and sectors is determined by how they are ordered in the meta-model. When using tags, the order is alphabetical. The radar report is limited to displaying up to seven rings. Therefore, the assigned field or tag can have a maximum of 7 values.
**Note**
  * If there are too many dots within a single segment, the report will instead display the number of fact sheets in that segment
  * The color code of the fact sheets depends on the ring and sector category.
